# Generated by Django 2.2.25 on 2022-01-14 15:50

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('aimmo', '0026_remove_worksheets'),
    ]

    operations = [
        migrations.AddField(
            model_name='game',
            name='creation_time',
            field=models.DateTimeField(default=django.utils.timezone.now, null=True),
        ),
        migrations.AddField(
            model_name='game',
            name='is_archived',
            field=models.BooleanField(default=False),
        ),
    ]
